@@ -19,5 +19,5 @@
 from ._version import __version__
 
 from .settings import (Settings)
-from .data import (Data)
+from .data import (Data, standardize)
 from .train import (train)
\ No newline at end of file
